pub mod svg;
use svg::*;

use askama::Template;
use derive_more::From;
use std::{fs::OpenOptions, io::Write};

#[derive(Template)]
#[template(path = "document.xml")]
struct DocumentTemplate {
    width: SVGMeasure,
    height: SVGMeasure,
}

#[derive(From, Debug)]
enum Error {
    Io(std::io::Error),
    Template(askama::Error),
}

fn main() -> Result<(), Error> {
    let mut file = OpenOptions::new()
        .write(true)
        .truncate(true)
        .create(true)
        .open("output.svg")?;
    let document = DocumentTemplate {
        width: SVGMeasure::new(8.5, SVGUnit::Inch),
        height: SVGMeasure::new(11.0, SVGUnit::Inch),
    };
    write!(file, "{}", document.render()?)?;
    Ok(())
}
