use super::SVGUnit;
use std::fmt;
use std::{
    fmt::Display,
    ops::{Add, Div, Mul, Sub},
};

pub struct SVGMeasure {
    pub measure: f64,
    pub unit: SVGUnit,
}

impl SVGMeasure {
    pub fn new(measure: f64, unit: SVGUnit) -> Self {
        Self { measure, unit }
    }
}

impl Display for SVGMeasure {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        write!(f, "{}{}", self.measure, self.unit)
    }
}

impl Add for SVGMeasure {
    type Output = Self;

    fn add(self, other: Self) -> Self {
        SVGMeasure::new(self.measure + other.measure, self.unit)
    }
}

impl Sub for SVGMeasure {
    type Output = Self;

    fn sub(self, other: Self) -> Self {
        SVGMeasure::new(self.measure - other.measure, self.unit)
    }
}

impl Mul<f64> for SVGMeasure {
    type Output = Self;

    fn mul(self, scalar: f64) -> Self {
        SVGMeasure::new(self.measure * scalar, self.unit)
    }
}

impl Div<f64> for SVGMeasure {
    type Output = Self;

    fn div(self, scalar: f64) -> Self {
        SVGMeasure::new(self.measure / scalar, self.unit)
    }
}
