use std::fmt::{self, Display};

/// https://oreillymedia.github.io/Using_SVG/guide/units.html
pub enum SVGUnit {
    /// Pixel units, directly equivalent to SVG user units.
    Pixel,
    /// Inches.
    Inch,
    /// Centimeters.
    Centimeter,
    /// Millimeters.
    Millimeter,
    /// Points.
    Point,
    // Picas.
    Pica,
    /// Em units. Equivalent to the computed font-size in effect for an element.
    Em,
    /// Ex units. Equivalent to the height of a lower-case letter in the font (and font-size) in effect for an element. If the font doesn’t include lower-case letters, or doesn’t include the metadata about the ex-height, then 1ex = 0.5em.
    Ex,
    /// Character units. Equivalent to the width of the `0` (zero) character in the font and font-size in effect for an element.
    Character,
    /// Root-em units. The font size of the root element in the document, regardless of any settings for the current element.
    Rem,
    /// Viewport width units. 1% of the viewport width.
    ViewportWidth,
    /// Viewport height units. 1% of the viewport height.
    ViewportHeight,
    /// Viewport minimum units. 1% of the viewport width or height, whichever is smaller.
    ViewportMinimum,
    /// Viewport maximum units. 1% of the viewport width or height, whichever is larger.
    ViewportMaximum,
}

impl Display for SVGUnit {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        use SVGUnit::*;
        write!(
            f,
            "{}",
            match &self {
                Pixel => "px",
                Inch => "in",
                Centimeter => "cm",
                Millimeter => "mm",
                Point => "pt",
                Pica => "pc",
                Em => "em",
                Ex => "ex",
                Character => "ch",
                Rem => "rem",
                ViewportWidth => "vw",
                ViewportHeight => "vh",
                ViewportMinimum => "vmin",
                ViewportMaximum => "vmax",
            }
        )
    }
}
